pub fn flush_mouth()Expand description
This flushes a mouth so that it will be automatically closed, next time it’s read Corresponds to TeX’s \endinput
pub fn flush_mouth()This flushes a mouth so that it will be automatically closed, next time it’s read Corresponds to TeX’s \endinput