read_arg

Function read_arg 

pub fn read_arg(expansion_level: ExpansionLevel) -> Result<Tokens>
Read and return a “normal” TeX argument

The next Token or Tokens (if surrounded by braces). expansion_level controls expansion as if the argument were read and then expanded in isolation:

In the case of a single unbraced expandable token, it will not read any macro arguments from the following input!