read_until

Function read_until 

pub fn read_until(delim: &Tokens) -> Result<Tokens>
Return a (balanced) sequence tokens until a match against one of the Tokens in @delims.

Note that Braces on input hides the contents from matching, so this assumes there wont be braces in $delim! But, see readUntilBrace for that case.