pub fn reading_from_mouth<R, FnR>(mouth: Mouth, reader: FnR) -> Result<R>Expand description
Do something, while reading tokens from a specific Mouth.
This reads ONLY from that mouth (or any mouth openned by code in that source), and the mouth should end up empty afterwards, and only be closed here.